==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/entity/EnderAirEntity.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.entity;

import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_2487;
import net.minecraft.class_2596;
import net.minecraft.class_2604;
import org.jetbrains.annotations.NotNull;

public class EnderAirEntity extends class_1297 {
	private static final String TAG_AGE = "Age";
	private static final int MAX_AGE = 3 * 20;

	public EnderAirEntity(class_1299<?> type, class_1937 level) {
		super(type, level);
	}

	@Override
	public void method_5773() {
		super.method_5773();
		if (!field_6002.field_9236 && field_6012 > MAX_AGE) {
			method_31472();
		}
		if (field_6002.field_9236 && field_5974.method_43056()) {
			float r = (EnderAirBottleEntity.PARTICLE_COLOR >> 16 & 0xFF) / 255.0F;
			float g = (EnderAirBottleEntity.PARTICLE_COLOR >> 8 & 0xFF) / 255.0F;
			float b = (EnderAirBottleEntity.PARTICLE_COLOR & 0xFF) / 255.0F;
			for (int i = 0; i < 5; i++) {
				double x = this.method_23317() + field_5974.method_43058();
				double y = this.method_23318() + field_5974.method_43058();
				double z = this.method_23321() + field_5974.method_43058();
				field_6002.method_8494(class_2398.field_11226, x, y, z, r, g, b);
			}
		}
	}

	@Override
	protected void method_5693() {}

	@Override
	protected void method_5749(@NotNull class_2487 tag) {
		field_6012 = tag.method_10550(TAG_AGE);
	}

	@Override
	protected void method_5652(@NotNull class_2487 tag) {
		tag.method_10569(TAG_AGE, field_6012);
	}

	@Override
	public class_2596<?> method_18002() {
		return new class_2604(this);
	}
}

==> Botania-1.20.1-449-FABRIC-20250801.190615-49-sources.jar: vazkii/botania/common/entity/EnderAirEntity.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.entity;

import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_2487;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2604;
import org.jetbrains.annotations.NotNull;

public class EnderAirEntity extends class_1297 {
	private static final String TAG_AGE = "Age";
	private static final int MAX_AGE = 3 * 20;

	public EnderAirEntity(class_1299<?> type, class_1937 level) {
		super(type, level);
	}

	@Override
	public void method_5773() {
		super.method_5773();
		if (!method_37908().field_9236 && field_6012 > MAX_AGE) {
			method_31472();
		}
		if (method_37908().field_9236 && field_5974.method_43056()) {
			float r = (EnderAirBottleEntity.PARTICLE_COLOR >> 16 & 0xFF) / 255.0F;
			float g = (EnderAirBottleEntity.PARTICLE_COLOR >> 8 & 0xFF) / 255.0F;
			float b = (EnderAirBottleEntity.PARTICLE_COLOR & 0xFF) / 255.0F;
			for (int i = 0; i < 5; i++) {
				double x = this.method_23317() + field_5974.method_43058();
				double y = this.method_23318() + field_5974.method_43058();
				double z = this.method_23321() + field_5974.method_43058();
				method_37908().method_8494(class_2398.field_11226, x, y, z, r, g, b);
			}
		}
	}

	@Override
	protected void method_5693() {}

	@Override
	protected void method_5749(@NotNull class_2487 tag) {
		field_6012 = tag.method_10550(TAG_AGE);
	}

	@Override
	protected void method_5652(@NotNull class_2487 tag) {
		tag.method_10569(TAG_AGE, field_6012);
	}

	@Override
	public class_2596<class_2602> method_18002() {
		return new class_2604(this);
	}
}
